# AggregationMetricType


## Enum

* `SKETCH` (value: `'sketch'`)

* `NUMERIC` (value: `'numeric'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


